
# Slot: classifier_id


Key to identify the classifier and associated parameters.

URI: [https://w3id.org/neat/classifier__classifier_id](https://w3id.org/neat/classifier__classifier_id)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Classifier](Classifier.md)
